$set 3 #Configmenu

$ #ConfigOptions
# Configuraes
$ #FocusModel
# Modelo de Foco
$ #WindowPlacement
# Posicionamento das Janelas
$ #ImageDithering
# Simulao de Cores em Imagens
$ #OpaqueMove
# Movimento Opaco de Janelas
$ #FullMax
# Maximizao Total
$ #FocusNew
# Foco em Novas Janelas
$ #FocusLast
# Foco na Ultima Janela Da Area de Trabalho
$ #ClickToFocus
# Foco na Janela Quando Clicada
$ #SloppyFocus
# Foco na Janela Quando Apontada
$ #AutoRaise
# Sobrepor Janela Quando Ativa
$ #SmartRows
# Posicionamento em Fila
$ #SmartCols
# Posicionamento em Coluna
$ #Cascade
# Posicionamento em Cascata
$ #LeftRight
# Esquerda para Direita
$ #RightLeft
# Direita para Esquerda
$ #TopBottom
# Cima para Baixo
$ #BottomTop
# Baixo para Cima
$ #Tabs
# Tabs
$ #Icons
# Icons
$ #TabPlacement
# Posicionamento da Tab
$ #TabRotateVertical
# Rodar Tabs Verticais
$ #SemiSloppyFocus
# Semi Focus Desordenado
$ #MaxOverSlit
# Maximizar Sobre Slit
$ #SloppyWindowGrouping
# Janela Em Grupo Desordenada
$ #WorkspaceWarping
# Alternando Workspace
$ #DesktopWheeling
# Rodando Area Trabalho
